Package 'icesConnect'

Title: Provides User Tokens for Access to ICES Web Services
Description: Provides user tokens for ICES web services that require authentication and authorization. Web services covered by this package are ICES VMS database, the ICES DATSU web services, and the ICES SharePoint site <https://www.ices.dk/data/tools/Pages/WebServices.aspx>.
Authors: Colin Millar [aut, cre]
Maintainer: Colin Millar <[email protected]>
License: GPL-3
Version: 1.2.0
Built: 2026-05-15 06:58:41 UTC
Source: https://github.com/ices-tools-prod/icesConnect

Help Index


Decode token

Description

Decodes the token to allow inspection of claims

Return the expiration date of the token

What user is this token for

Usage

decode_token(jwt = ices_token(), formatted = TRUE)

token_expiration(jwt = ices_token())

token_user(jwt = ices_token())

Arguments

jwt

a javascript web token got by running ices_token()

formatted

should formatted output be returned

Value

list of claims

POSIXct date time

string, user

Examples

## Not run: 
decode_token()

## End(Not run)

## Not run: 
token_expiration()

## End(Not run)

## Not run: 
token_user()

## End(Not run)

ices_request_jwt

Description

Perform a get request to a url using a javascript web token for authentication

Usage

ices_get(
  url,
  retry = TRUE,
  quiet = FALSE,
  verbose = FALSE,
  content = TRUE,
  use_token = FALSE,
  jwt = NULL
)

ices_get_jwt(url, retry = TRUE, quiet = FALSE, verbose = FALSE, jwt = NULL)

ices_patch_jwt(
  url,
  body = list(),
  encode = "json",
  retry = TRUE,
  quiet = FALSE,
  verbose = FALSE,
  jwt = NULL
)

ices_post(
  url,
  body = list(),
  retry = TRUE,
  verbose = FALSE,
  content = TRUE,
  use_token = TRUE,
  encode = "multipart"
)

ices_post_jwt(
  url,
  body = list(),
  encode = "json",
  retry = TRUE,
  quiet = FALSE,
  verbose = FALSE,
  jwt = NULL
)

ices_request_jwt(
  type = c("GET", "POST", "PATCH"),
  url,
  body = NULL,
  encode = c("multipart", "form", "json", "raw"),
  retry = TRUE,
  quiet = FALSE,
  verbose = FALSE,
  jwt = NULL
)

Arguments

url

the url to make the request to

retry

if initial request fails, should a retry be made, Default: TRUE

quiet

suppress informative messages to the console

verbose

should the http request return verbose output

content

logical, if TRUE the content of the response is returned, if FALSE the http response object is returned

use_token

logical, if TRUE the token is used, if FALSE the token is not used

jwt

option to supply a token bypassing the ices_token() route, if "" no token is used

body

optional body of request

encode

If the body is a named list, how should it be encoded?

type

the type of request to make, GET, POST or PATCH

Value

http response object

See Also

ices_token GET,add_headers,stop_for_status,status_code

Examples

## Not run: 
# this function is interactive and asks the user for a password
ices_request_jwt("GET", "https://taf.ices.dk/vms/api/gearwidths")
ices_get_jwt("https://taf.ices.dk/vms/api/gearwidths")

the top level function
ices_get("https://taf.ices.dk/vms/api/gearwidths", content = FALSE, use_token = TRUE)
ices_get("https://taf.ices.dk/vms/api/gearwidths", content = TRUE)

## End(Not run)

ices_token

Description

Stores a user token in the system keyring

Usage

ices_token(...)

Arguments

...

not yet used

Value

character scalar, the token

Examples

## Not run: 
ices_token()

## End(Not run)

Set your ICES username

Description

Back compatability function that does nothing.

Usage

set_username(...)

Arguments

...

only here for back compatability, does nothing

Value

invisible NULL